--addon name, addon namespace
local _, ans = ...;

local hideTimer;
local barNames = {};

local function ActionBars_load()
    local barsToUpdate = {
        {name = "MainMenuBar", toUpdate = KdoUiData.ShowMainMenuBarOnHover},
        {name = "MultiBarBottomLeft", toUpdate = KdoUiData.ShowMultiBarBottomLeftOnHover},
        {name = "MultiBarBottomRight", toUpdate = KdoUiData.ShowMultiBarBottomRightOnHover},
        {name = "MultiBarRight", toUpdate = KdoUiData.ShowMultiBarRightOnHover},
        {name = "MultiBarLeft", toUpdate = KdoUiData.ShowMultiBarLeftOnHover},
        {name = "MultiBar5", toUpdate = KdoUiData.ShowMultiBar5OnHover},
        {name = "MultiBar6", toUpdate = KdoUiData.ShowMultiBar6OnHover},
        {name = "MultiBar7", toUpdate = KdoUiData.ShowMultiBar7OnHover},
        {name = "StanceBar", toUpdate = KdoUiData.ShowStanceBarHover},
        {name = "PetActionBar", toUpdate = KdoUiData.ShowPetActionBarHover}
    }
    
    for _, barToUpdate in ipairs(barsToUpdate) do
        if (barToUpdate.toUpdate) then
            table.insert(barNames, barToUpdate.name);
        end
    end

    local function setBarsAlpha(alpha)
        for _, barName in ipairs(barNames) do
            _G[barName]:SetAlpha(alpha);
        end
    end

    local function show()
        ans.cancelTimer(hideTimer);
        setBarsAlpha(1);
    end
    
    local function hide()
        hideTimer = ans.createTimer(function()
            setBarsAlpha(0);
        end);
    end
    
    for _, barName in ipairs(barNames) do
        local bar = _G[barName];
        bar:HookScript("OnEnter", show);
        bar:HookScript("OnLeave", hide);

        local buttonPrefix = barName;
        if (barName == "MainMenuBar") then
            buttonPrefix = "Action";
        end
        if (barName == "StanceBar") then
            buttonPrefix = "Stance"
        end
        if (barName == "PetActionBar") then
            buttonPrefix = "PetAction"
        end
        for i = 1, 12 do
            local button = _G[buttonPrefix.."Button"..i];
            local cd = _G[buttonPrefix.."Button"..i.."Cooldown"];
            if (button) then
                button:HookScript("OnEnter", show);
                button:HookScript("OnLeave", hide);
            end
            if (cd) then
                cd:SetDrawBling(false); -- hide end of gcd effect
            end
        end
    end

    hide();
end

ans.ActionBars_load = ActionBars_load;